Direct API Calls:
- direct_api: add, list, show, call, test, update, remove endpoints. auth_from_browser to capture tokens.
- Supported methods: GET, POST, PUT, PATCH (no DELETE). call_id accepts ID, name, or #index.